gchecky.model.shipping_in_calculate_t

Package gchecky :: Module model :: Class shipping_in_calculate_t |
[hide private]
[frames] | no frames]

# Class shipping_in_calculate_t

source code

    object --+
             |
     gxml.Node --+
                 |
                shipping_in_calculate_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| methods = `List:PATH():RE`...``
| _fields = ``{``'``methods``'``:` List:PATH():RE`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### methods Value:
      List:PATH():REQ:[
          String:PATH(method@name):REQ
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'methods': List:PATH():REQ:[
          String:PATH(method@name):REQ
      ]}